"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Translate;

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _react = _interopRequireWildcard(require("react"));

var _server = require("react-dom/server");

var _LocaleProvider = _interopRequireDefault(require("./LocaleProvider"));

var _NamespaceContext = _interopRequireDefault(require("./NamespaceContext"));

var _TranslateContext = _interopRequireDefault(require("./TranslateContext"));

function prepareParams(params, translate) {
  const newParams = {};
  let changed = false;
  Object.keys(params).forEach(key => {
    const value = params[key];
    const isReactElement = (0, _react.isValidElement)(value);

    if (!isReactElement) {
      newParams[key] = value;
    } else {
      changed = true;
      newParams[key] = (0, _server.renderToStaticMarkup)(_react.default.createElement(_LocaleProvider.default, {
        translate: translate
      }, value));
    }
  });
  return changed ? newParams : params;
}

function Translate(props) {
  const {
    path,
    description,
    defaultValue,
    params,
    children,
    html
  } = props,
        rest = (0, _objectWithoutProperties2.default)(props, ["path", "description", "defaultValue", "params", "children", "html"]);
  const namespace = (0, _react.useContext)(_NamespaceContext.default);
  const translate = (0, _react.useContext)(_TranslateContext.default);
  const finallPath = namespace ? `${namespace}.${path}` : path;
  const updatedDefaultValue = !defaultValue && typeof children === 'string' ? children : defaultValue;
  const updatedParams = prepareParams(params || rest, translate);
  const text = translate.get(finallPath, updatedParams, updatedDefaultValue) || '';

  if (typeof children === 'function') {
    return children(text);
  }

  if (html) {
    return _react.default.createElement("span", {
      dangerouslySetInnerHTML: {
        __html: text
      }
    });
  }

  return text;
}

Translate.defaultProps = {
  defaultValue: undefined,
  description: undefined,
  params: undefined,
  children: undefined,
  html: false
};
//# sourceMappingURL=Translate.js.map