"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = Translate;

var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));

var _react = _interopRequireWildcard(require("react"));

var _server = require("react-dom/server");

var _LocaleProvider = _interopRequireDefault(require("./LocaleProvider"));

var _NamespaceContext = _interopRequireDefault(require("./NamespaceContext"));

var _TranslateContext = _interopRequireDefault(require("./TranslateContext"));

function prepareParams(params, translate) {
  var newParams = {};
  var changed = false;
  Object.keys(params).forEach(function (key) {
    var value = params[key];
    var isReactElement = (0, _react.isValidElement)(value);

    if (!isReactElement) {
      newParams[key] = value;
    } else {
      changed = true;
      newParams[key] = (0, _server.renderToStaticMarkup)(_react.default.createElement(_LocaleProvider.default, {
        translate: translate
      }, value));
    }
  });
  return changed ? newParams : params;
}

function Translate(props) {
  var path = props.path,
      description = props.description,
      defaultValue = props.defaultValue,
      params = props.params,
      children = props.children,
      html = props.html,
      rest = (0, _objectWithoutPropertiesLoose2.default)(props, ["path", "description", "defaultValue", "params", "children", "html"]);
  var namespace = (0, _react.useContext)(_NamespaceContext.default);
  var translate = (0, _react.useContext)(_TranslateContext.default);
  var finallPath = namespace ? namespace + "." + path : path;
  var updatedDefaultValue = !defaultValue && typeof children === 'string' ? children : defaultValue;
  var updatedParams = prepareParams(params || rest, translate);
  var text = translate.get(finallPath, updatedParams, updatedDefaultValue) || '';

  if (typeof children === 'function') {
    return children(text);
  }

  if (html) {
    return _react.default.createElement("span", {
      dangerouslySetInnerHTML: {
        __html: text
      }
    });
  }

  return text;
}

Translate.defaultProps = {
  defaultValue: undefined,
  description: undefined,
  params: undefined,
  children: undefined,
  html: false
};
//# sourceMappingURL=Translate.js.map