import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React, { useContext, isValidElement } from 'react';
import { renderToStaticMarkup } from 'react-dom/server';
import LocaleProvider from './LocaleProvider';
import NamespaceContext from './NamespaceContext';
import TranslateContext from './TranslateContext';

function prepareParams(params, translate) {
  const newParams = {};
  let changed = false;
  Object.keys(params).forEach(key => {
    const value = params[key];
    const isReactElement = isValidElement(value);

    if (!isReactElement) {
      newParams[key] = value;
    } else {
      changed = true;
      newParams[key] = renderToStaticMarkup(React.createElement(LocaleProvider, {
        translate: translate
      }, value));
    }
  });
  return changed ? newParams : params;
}

export default function Translate(props) {
  const {
    path,
    description,
    defaultValue,
    params,
    children,
    html
  } = props,
        rest = _objectWithoutProperties(props, ["path", "description", "defaultValue", "params", "children", "html"]);

  const namespace = useContext(NamespaceContext);
  const translate = useContext(TranslateContext);
  const finallPath = namespace ? `${namespace}.${path}` : path;
  const updatedDefaultValue = !defaultValue && typeof children === 'string' ? children : defaultValue;
  const updatedParams = prepareParams(params || rest, translate);
  const text = translate.get(finallPath, updatedParams, updatedDefaultValue) || '';

  if (typeof children === 'function') {
    return children(text);
  }

  if (html) {
    return React.createElement("span", {
      dangerouslySetInnerHTML: {
        __html: text
      }
    });
  }

  return text;
}
Translate.defaultProps = {
  defaultValue: undefined,
  description: undefined,
  params: undefined,
  children: undefined,
  html: false
};
//# sourceMappingURL=Translate.js.map